@@ -5,14 +5,15 @@ test_that("gsw seasonality works", {
     )
   )
 
-  x <- suppressWarnings(st_cast(x, to = "POLYGON")[1, ])
+  .clear_resources()
+  outdir <- file.path(tempdir(), "mapme.data")
+  .copy_resource_dir(outdir)
+  mapme_options(outdir = outdir, verbose = FALSE)
+  get_resources(x, get_global_surface_water_seasonality(version = "v1_4_2021"))
+  gsw_seasonality <- prep_resources(x)[["global_surface_water_seasonality"]][[1]]
+
   gsws <- calc_gsw_seasonality()
   expect_true(is.null(gsws(x, NULL)))
-
-  gsw_seasonality <- list.files(system.file("res", "gsw_seasonality",
-    package = "mapme.biodiversity"
-  ), pattern = ".tif$", full.names = TRUE)
-  gsw_seasonality <- rast(gsw_seasonality)
   season <- gsws(x, gsw_seasonality)
   expect_equal(season$value,
     c(2514.759, 22.461, 18.045, 23.831, 19.872, 2.512, 0.152, 0, 0, 0, 0, 0, 617.104),
