@@ -1,16 +1,21 @@
 test_that("soilpoperties works", {
+  skip_on_cran()
+  skip_if_not(Sys.getenv("USER") == "darius")
+
   x <- read_sf(
     system.file("extdata", "sierra_de_neiba_478140.gpkg",
       package = "mapme.biodiversity"
     )
   )
-  x <- suppressWarnings(st_cast(x, to = "POLYGON"))[1, ]
 
-  soilgrids <- list.files(system.file("res", "soilgrids",
-    package = "mapme.biodiversity"
-  ), pattern = ".tif$", full.names = TRUE)
-
-  soilgrids <- rast(soilgrids)
+  mapme_options(outdir = NULL, verbose = FALSE)
+  suppressWarnings(get_resources(x, get_soilgrids(
+    layer = "clay",
+    depth = "0-5cm",
+    stat = "mean"
+  )))
+  soilgrids <- prep_resources(x)[["soilgrids"]]
+  x <- st_transform(x, st_crs(soilgrids))
 
   csp <- calc_soilproperties()
   expect_true(is.null(csp(x, NULL)))
